@@ -2,4 +2,4 @@
 # this tests whether all required args are listed as
 # missing when no arguments are specified
 # failure  
-./simple-test.sh `basename $0 .sh` test12 
+`dirname $0`/simple-test.sh `basename $0 .sh` test12 
