@@ -1,4 +1,4 @@
 #!/bin/sh
 # Checks that parsing exceptions are properly
 # propagated to the caller.
-./simple-test.sh `basename $0 .sh` test18 --help
+`dirname $0`/simple-test.sh `basename $0 .sh` test18 --help
